L2Cost — skchange

Skip to main content
`Ctrl`+`K`

# L2Cost

L2Cost(param: _SupportsArray[dtype[Any]] | _NestedSequence[_SupportsArray[dtype[Any]]] | bool | int | float | complex | str | bytes | _NestedSequence[bool | int | float | complex | str | bytes] | Number | None = None)

  L2 cost of a constant mean.

  Parameters:
    paramfloat or array-like, optional (default=None)

      Fixed mean for the cost calculation. If None, the optimal mean is calculated.